<?php
/*
Plugin Name: Efficient Multisite Manager
Plugin URI: http://efficientwp.com/efficient-multisite-manager
Description: This plugin provides network admins with additional multisite management capabilities. It makes it easier to monitor and change individual site options on a multisite install. Only for WordPress installations with multisite enabled. 
Version: 0.8
Author: Doug Yuen
Author URI: http://efficientwp.com
License: GPLv2
*/

add_action( 'init', 'ew_emm_init' );
add_action( 'admin_bar_menu', 'ew_emm_my_admin_bar_menu', 1000 );
register_activation_hook( __FILE__, 'ew_emm_install' );

function ew_emm_my_admin_bar_menu() {

	/* ADDS NEW ADMIN BAR MENU */
	
	global $wp_admin_bar, $wpdb;
	if ( is_super_admin() && is_multisite() && current_user_can( 'manage_network' ) && is_admin_bar_showing() ) {
		$wp_admin_bar->add_menu(
			array(
				'id' => 'ew_emm_custom_menu',
				'title' => __( 'Network' ),
				'href' => ( get_blog_details( 1 )->domain . '/wp-admin/network/' )
			)
		);
		$wp_admin_bar->add_menu(
			array(
				'id' => 'ew_emm',
				'parent' => 'ew_emm_custom_menu',
				'title' => __( 'Efficient Multisite Manager' ),
				'href' => admin_url( '/index.php?page=efficient-multisite-manager/efficient-multisite-manager.php' )
			)
		);
		$wp_admin_bar->add_menu(
			array(
				'parent' => 'ew_emm',
				'title' => __( 'Site Overview' ),
				'href' => admin_url( '/index.php?page=efficient-multisite-manager/efficient-multisite-manager.php&subpage=site-overview' )
			)
		);
		$wp_admin_bar->add_menu(
			array(
				'parent' => 'ew_emm',
				'title' => __( 'Site Options' ),
				'href' => admin_url( '/index.php?page=efficient-multisite-manager/efficient-multisite-manager.php&subpage=site-options' )
			)
		);
		$wp_admin_bar->add_menu(
			array(
				'parent' => 'ew_emm',
				'title' => __( 'Stats' ),
				'href' => admin_url( '/index.php?page=efficient-multisite-manager/efficient-multisite-manager.php&subpage=stats' )
			)
		);
		$wp_admin_bar->add_menu(
			array(
				'parent' => 'ew_emm',
				'title' => __( 'Settings' ),
				'href' => admin_url( '/index.php?page=efficient-multisite-manager/efficient-multisite-manager.php&subpage=settings' )
			)
		);
		$wp_admin_bar->add_menu(
			array(
				'id' => 'ew_emm_sites',
				'parent' => 'ew_emm_custom_menu',
				'title' => __( 'Sites' ),
				'href' => ( get_blog_details( 1 )->domain . '/wp-admin/network/sites.php' )
			)
		);
		$wp_admin_bar->add_menu(
			array(
				'parent' => 'ew_emm_sites',
				'title' => __( 'Add New Site' ),
				'href' => ( get_blog_details( 1 )->domain . '/wp-admin/network/site-new.php' )
			)
		);
		$wp_admin_bar->add_menu(
			array(
				'id' => 'ew_emm_users',
				'parent' => 'ew_emm_custom_menu',
				'title' => __( 'Users' ),
				'href' => ( get_blog_details( 1 )->domain . '/wp-admin/network/users.php' )
			)
		);
		$wp_admin_bar->add_menu(
			array(
				'parent' => 'ew_emm_users',
				'title' => __( 'Add New User' ),
				'href' => ( get_blog_details( 1 )->domain . '/wp-admin/network/user-new.php' )
			)
		);
		$wp_admin_bar->add_menu(
			array(
				'id' => 'ew_emm_themes',
				'parent' => 'ew_emm_custom_menu',
				'title' => __( 'Themes' ),
				'href' => ( get_blog_details( 1 )->domain . '/wp-admin/network/themes.php' )
			)
		);
		$wp_admin_bar->add_menu(
			array(
				'parent' => 'ew_emm_themes',
				'title' => __( 'Install Themes' ),
				'href' => ( get_blog_details( 1 )->domain . '/wp-admin/network/theme-install.php' )
			)
		);
		$wp_admin_bar->add_menu(
			array(
				'id' => 'ew_emm_plugins',
				'parent' => 'ew_emm_custom_menu',
				'title' => __( 'Plugins' ),
				'href' => ( get_blog_details( 1 )->domain . '/wp-admin/network/plugins.php' )
			)
		);
		$wp_admin_bar->add_menu(
			array(
				'parent' => 'ew_emm_plugins',
				'title' => __( 'Install Plugins' ),
				'href' => ( get_blog_details( 1 )->domain . '/wp-admin/network/plugin-install.php' )
			)
		);
		$wp_admin_bar->add_menu(
			array(
				'id' => 'ew_emm_settings',
				'parent' => 'ew_emm_custom_menu',
				'title' => __( 'Settings' ),
				'href' => ( get_blog_details( 1 )->domain . '/wp-admin/network/settings.php' )
			)
		);
	}
}

function ew_emm_init() {
	if ( is_super_admin() && is_multisite() && current_user_can( 'manage_network' ) ) {
		require_once( dirname(__FILE__) . '/includes/utility-functions.php' );
		add_action( 'admin_menu', 'ew_emm' );
	}
}

function ew_emm() {
	add_dashboard_page( 'Efficient Multisite Manager', 'Efficient Multisite Manager', 'manage_network', (__FILE__), 'ew_emm_display' );
}

function ew_emm_declare_variables() {

	/* DECLARE VARIABLES */
	
	global $user_ID, $wpdb;

	$options_variable = 'ew_emm_sites_options';
	$site_options = get_user_meta( $user_ID, $options_variable, 1 );
	if ( empty( $site_options ) ) {
		$site_options = array(
			'1'=> array (
				'display_order'=>'1',
				'show'=>'on',
				'display_name'=>'Site Name',
				'option_name'=>'blogname',
				'alert_if_not_equal_to'=>'',
				'alert_if_equal_to'=>'',
				'explanation'=>'The website name.'),
			'2'=> array (
				'display_order'=>'2',
				'show'=>'off',
				'display_name'=>'Description',
				'option_name'=>'blogdescription',
				'alert_if_not_equal_to'=>'',
				'alert_if_equal_to'=>'',
				'explanation'=>'The website description or tagline.'),
			'3'=> array (
				'display_order'=>'3',
				'show'=>'off',
				'display_name'=>'Admin Email',
				'option_name'=>'admin_email',
				'alert_if_not_equal_to'=>'',
				'alert_if_equal_to'=>'',
				'explanation'=>'The administrator email address for the website.'),
			'4'=> array (
				'display_order'=>'4',
				'show'=>'on',
				'display_name'=>'Permalinks',
				'option_name'=>'permalink_structure',
				'alert_if_not_equal_to'=>'',
				'alert_if_equal_to'=>'',
				'explanation'=>'The format to use for your post URLs. This does not change your page URLs, except if you do not use a trailing slash, your page titles will also not use a trailing slash.'),
			'5'=> array (
				'display_order'=>'5',
				'show'=>'on',
				'display_name'=>'Search Engine Ready?',
				'option_name'=>'blog_public',
				'alert_if_not_equal_to'=>'',
				'alert_if_equal_to'=>'',
				'explanation'=>'Whether or not to let search engines crawl and index your website. Use 1 to allow and 0 to disallow.'),
			'6'=> array (
				'display_order'=>'6',
				'show'=>'off',
				'display_name'=>'Timezone',
				'option_name'=>'timezone_string',
				'alert_if_not_equal_to'=>'',
				'alert_if_equal_to'=>'',
				'explanation'=>'Your timezone.'),
			'7'=> array (
				'display_order'=>'7',
				'show'=>'off',
				'display_name'=>'XML-RPC',
				'option_name'=>'enable_xmlrpc',
				'alert_if_not_equal_to'=>'',
				'alert_if_equal_to'=>'',
				'explanation'=>'Enabling XML-RPC will allow you to edit your website with a third-party service, such as a mobile app. Use 1 to allow and 0 to disallow.'),
			'8'=> array (
				'display_order'=>'8',
				'show'=>'off',
				'display_name'=>'Theme',
				'option_name'=>'current_theme',
				'alert_if_not_equal_to'=>'',
				'alert_if_equal_to'=>'',
				'explanation'=>'The theme to use for the website. If you change this, you will probably need to change the Template and Stylesheet values as well.'),
			'9'=> array (
				'display_order'=>'9',
				'show'=>'off',
				'display_name'=>'Template',
				'option_name'=>'template',
				'alert_if_not_equal_to'=>'',
				'alert_if_equal_to'=>'',
				'explanation'=>'The template to use for the website. This is generally dependent on the theme you choose. If you change this, you will probably need to change the Current Theme and Stylesheet values as well.'),
			'10'=> array (
				'display_order'=>'10',
				'show'=>'off',
				'display_name'=>'Stylesheet',
				'option_name'=>'stylesheet',
				'alert_if_not_equal_to'=>'',
				'alert_if_equal_to'=>'',
				'explanation'=>'The stylesheet to use for the website. This is generally dependent on the theme you choose. If you change this, you will probably need to change the Current Theme and Template values as well.'),
			'11'=> array (
				'display_order'=>'11',
				'show'=>'off',
				'display_name'=>'Show on Front',
				'option_name'=>'show_on_front',
				'alert_if_not_equal_to'=>'',
				'alert_if_equal_to'=>'',
				'explanation'=>'If you want to use your home page for blog posts, use the value: posts. If you want to use a static page, use the value: page.'),
			'12'=> array (
				'display_order'=>'12',
				'show'=>'off',
				'display_name'=>'Page on Front',
				'option_name'=>'page_on_front',
				'alert_if_not_equal_to'=>'',
				'alert_if_equal_to'=>'',
				'explanation'=>'The ID of the static page you want to use as your home page. Usually this ID is 2 if you are renaming the default About page to Home. For a blog front page, use 0.'),
			'13'=> array (
				'display_order'=>'13',
				'show'=>'off',
				'display_name'=>'Page for Posts',
				'option_name'=>'page_for_posts',
				'alert_if_not_equal_to'=>'',
				'alert_if_equal_to'=>'',
				'explanation'=>'The ID of the static page you want to use to display your blog posts. The posts will overwrite any content on this static page. If you are not displaying posts, use 0.'),
		);
		update_user_meta( $user_ID, $options_variable, $site_options );
	}
	$options_variable = 'ew_emm_settings';
	$ew_emm_settings = get_user_meta( $user_ID, $options_variable, 1 );
	if ( empty( $ew_emm_settings ) ) {
		$ew_emm_settings = array(
			'highly_recommended_plugins' => array( 'black-studio-tinymce-widget', 'cms-page-order', 'my-custom-css', 'simple-301-redirects', 'tinymce-advanced' ),
			'other_recommended_plugins' => array ( 'akismet', 'display-posts-shortcode', 'duplicate-post', 'google-analyticator', 'gravityforms', 'j-shortcodes', 'lightbox-plus', 'nextgen-gallery', 'simple-social-icons', 'socialize', 'wordpress-seo', 'wp-google-fonts' ),
			'alert_styles' => 'background-color:#FFFF33; padding:3px;',
			'highly_recommended_plugins_styles' => 'background-color:#CC0000; color:#CCCCCC; padding:3px;',
			'other_recommended_plugins_styles' => 'background-color:#FFFF33; padding:3px;',
		);
		update_user_meta( $user_ID, $options_variable, $ew_emm_settings );
	}
}

function ew_emm_display() {

	ew_emm_declare_variables();

	/* DISPLAY THE APPROPRIATE PAGE CONTENT */
	
	$subpage = $_GET['subpage'];
	echo '<div class="wrap">';
	if ( $subpage == 'site-options' ) {
		require_once( dirname(__FILE__) . '/includes/site-options.php' );
		echo ew_emm_display_header( 'site-options', 'Site Options' );
		ew_emm_site_options();
	} elseif ( $subpage == 'stats' ) {
		require_once( dirname(__FILE__) . '/includes/stats.php' );
		echo ew_emm_display_header( 'stats', 'Stats' );
		ew_emm_stats();
	} elseif ( $subpage == 'settings' ) {
		require_once( dirname(__FILE__) . '/includes/settings.php' );
		echo ew_emm_display_header( 'settings', 'Settings' );
		ew_emm_settings();
	} else {
		require_once( dirname(__FILE__) . '/includes/site-overview.php' );
		echo ew_emm_display_header( 'site-overview', 'Site Overview' );
		ew_emm_site_overview();
	}
	echo '</div>';
}

function ew_emm_display_header( $current_page, $page_name ) {

	/* DISPLAY THE NAVIGATION MENU */
	
	$output_string .= get_screen_icon( 'plugins' ) . '<h2 class="nav-tab-wrapper">Efficient Multisite Manager<br /><br />';
	$output_string .= '<a class="nav-tab' . ew_emm_modify_navigation_button($current_page, 'site-overview') . '" href="?page=efficient-multisite-manager/efficient-multisite-manager.php&subpage=site-overview">Site Overview</a>';
	$output_string .= '<a class="nav-tab' . ew_emm_modify_navigation_button($current_page, 'site-options') . '" href="?page=efficient-multisite-manager/efficient-multisite-manager.php&subpage=site-options">Site Options</a>';
	$output_string .= '<a class="nav-tab' . ew_emm_modify_navigation_button($current_page, 'stats') . '" href="?page=efficient-multisite-manager/efficient-multisite-manager.php&subpage=stats">Stats</a>';
	$output_string .= '<a class="nav-tab' . ew_emm_modify_navigation_button($current_page, 'settings') . '" href="?page=efficient-multisite-manager/efficient-multisite-manager.php&subpage=settings">Settings</a>';
	$output_string .= '</h2><br />';
	return $output_string;
}

function ew_emm_modify_navigation_button( $current_page, $page_name ) {

	/* ADDS THE ACTIVE CSS CLASS IF IT IS THE CURRENT PAGE */
	
	if ( $current_page == $page_name ) {
		return " nav-tab-active";
	} else {
		return "";
	}
}

function ew_emm_install() {
  /* Need to create default activation settings */
}

?>