<?php

/* STATS PAGE */

function ew_emm_stats() {

	/* DECLARE VARIABLES */
	
	global $user_ID, $wpdb;
	$result = $wpdb->get_results( $wpdb->prepare( "SELECT blog_id, domain FROM $wpdb->blogs WHERE deleted = '0' ORDER BY blog_id ASC" ) );
	if ( is_plugin_active_for_network( 'domain-mapping/domain-mapping.php' ) ) {
	  $result_mapped_domains = $wpdb->get_var( $wpdb->prepare( "SELECT COUNT(*) FROM wp_domain_mapping WHERE active = '1'" ) );
	} else {
	  $result_mapped_domains = 0;
	}
    $mapped_domains = 0;
	$parent_domain = get_blog_details( 1 )->domain;
	$current_date = date ( 'Y-m-d' );
	$current_year = date ( 'Y' );
	$current_month = date ( 'm' );
	$current_day = date ( 'd' );
	$days_out_of_date = 365;
	
	/* SET UP EMPTY THEME ARRAY */
	
	$theme_array = array();
	foreach( get_themes() as $theme => $values) {
		$theme_array[$theme]['count'] = 0;
	}
	ksort( $theme_array );
	
	/* SET UP EMPTY PLUGIN ARRAY */
	
	$plugin_array = array();
	foreach( get_plugins() as $plugin => $values) {
		if ( strpos( $plugin, "/" ) != FALSE ) {
			$plugin_name = substr( $plugin, 0, strpos( $plugin, "/" ) );
			$plugin_array[$plugin_name]['count'] = 0;
		}
	}
	$network_activated_plugins = array();
	$temp_array = get_site_option( 'active_sitewide_plugins' );
	foreach( $temp_array as $plugin_path => $values ) {
		if ( strpos( $plugin_path, "/" ) != FALSE ) {
			$plugin_name = substr( $plugin_path, 0, strpos( $plugin_path, "/" ) );
			array_push( $network_activated_plugins, $plugin_name );
		}
	}
	ksort( $plugin_array );
	
	/* PULL INFO FROM DATABASE */
	
	foreach ( $result as $row ) {
	
		/* COUNT MAPPED DOMAINS */
		
		if ( ( $result_mapped_domains == 0 ) && ( strstr( $row->domain, $parent_domain ) === FALSE ) ) { 
	    	$mapped_domains++;
		}
	
		/* RETRIEVE OPTIONS VALUES FROM DATABASE */
		
		$site_options_table = substr( $wpdb->prefix, 0, strpos( $wpdb->prefix, '_' ) + 1 ) . $row->blog_id . '_options';
		$temp = 'SELECT option_name, option_value FROM ' . $site_options_table . ' WHERE option_name = "siteurl" OR option_name = "current_theme" OR option_name = "active_plugins"';
		$result2 = $wpdb->get_results( $temp );
		$result3 = array();
		foreach ( $result2 as $row2 ) {
			$result3[$row2->option_name] = $row2->option_value;
		}
		$siteurl = $result3['siteurl'];
		
		/* POPULATE THEME ARRAY */
		
		$current_theme = $result3['current_theme'];
		$theme_array[$current_theme]['count']++;
		$theme_array[$current_theme]['site_frontends'] .= ( '<a href="' . $siteurl . '" target="_blank">' . $siteurl . '</a><br />' );
		$theme_array[$current_theme]['site_backends'] .= ( '<a href="' . $siteurl . 'wp-admin/" target="_blank">Backend</a><br />' );
		
		/* POPULATE PLUGIN ARRAY */
		
		$active_plugins = array();
		$plugins = explode( '"', $result3['active_plugins'] );
		foreach ( $plugins as $plugin ) {
			if ( strpos( $plugin, "/" ) != FALSE ) {
				$current_plugin = substr( $plugin, 0, strpos( $plugin, "/" ) );
				$plugin_array[$current_plugin]['count']++;
				$plugin_array[$current_plugin]['site_frontends'] .= ( '<a href="' . $siteurl . '" target="_blank">' . $siteurl . '</a><br />' );
				$plugin_array[$current_plugin]['site_backends'] .= ( '<a href="' . $siteurl . 'wp-admin/" target="_blank">Backend</a><br />' );
			}
		}
	}
	
	/* DISPLAY DOMAIN STATS */
	
	$total_domains = count( $result );
	echo '<h2>Domain Stats</h2>';
	echo '<p>Total Domains: ' . $total_domains . '</p>';
	if ( $result_mapped_domains > $mapped_domains ) {
		$mapped_domains = $result_mapped_domains;
	}
	if ( $mapped_domains != 0 ) {
    	echo '<p>Mapped Domains: ' . $mapped_domains . '</p>';
	}

	/* DISPLAY PLUGIN STATS TABLE */
	
	echo '<h2>Plugin Stats</h2>';
	echo '<p>Plugins Installed: ' . count( $plugin_array ) . '</p>';
	echo '<table id="ew_emm_table" class="widefat">';
	
	/* DISPLAY TABLE HEADERS */
	
	echo '<thead><tr><th>Plugin</th><th>Last Modified <img src="' . plugins_url( 'images/help.png', dirname(__FILE__) ) . '" title="The last modified date of the most recently modified file in the plugin directory. Plugins whose files have not been updated in over a year are marked with red text. Note: this is not the date the plugin was last upgraded." style="vertical-align:middle;" /></th><th>Count</th><th>Usage</th><th>Sites Used On</th><th> </th></tr></thead>';
	
	/* DISPLAY TABLE ROWS */
	
	$background_image = plugins_url( 'images/green-pixel.png', dirname(__FILE__) );
	foreach ( $plugin_array as $plugin => $value ) {
		$percent_usage = round( ( $value['count'] / $total_domains * 100 ), 2 );
		$plugin_directory = WP_CONTENT_DIR . '/plugins/' . $plugin . '/.';
		$last_modified_date = date ( 'Y-m-d', filemtime( $plugin_directory ) );
		$last_modified_year = date ( 'Y', filemtime( $plugin_directory ) );
		$last_modified_month = date ( 'm', filemtime( $plugin_directory ) );
		$last_modified_day = date ( 'd', filemtime( $plugin_directory ) );
		echo '<tr><td>' . $plugin . '</td><td>';
		if ( ew_emm_get_days_between($last_modified_year, $last_modified_month, $last_modified_day, $current_year, $current_month, $current_day) > $days_out_of_date ) {
			echo '<span style="color:red;">' . $last_modified_date . '</span>';
		} else {
			echo $last_modified_date;
		}
		echo '</td>';
		echo '<td>';
		if ( in_array( $plugin, $network_activated_plugins ) ) {
			echo $total_domains;
		} else {
			echo $value['count'];
		}
		echo '</td><td>';
		if ( in_array( $plugin, $network_activated_plugins ) ) {
			echo '<div style="background-color:#01B400; width:100px; color:#000000;">&nbsp;Network Activated</div>';
		} else {
			echo '<div style="background:url(' . $background_image . '); background-size:' . $percent_usage . 'px 20px; background-repeat:no-repeat; width:100px; color:#000000;"><b>&nbsp;' . $percent_usage . '%</b></div>';
		}
		echo '</td>';
		echo '<td>' . $value['site_frontends'] . '</td><td>' . $value['site_backends'] . '</td></tr>';
	}
	echo '</table><br />';
	
	/* DISPLAY THEME STATS TABLE */
	
	echo '<h2>Theme Stats</h2>';
	echo '<p>Themes Installed: ' . count( $theme_array ) . '</p>';
	echo '<table id="ew_emm_table" class="widefat">';
	
	/* DISPLAY TABLE HEADERS */
	
	echo '<thead><tr><th>Theme</th><th>Count</th><th>Usage</th><th>Sites Used On</th><th> </th></tr></thead>';
	
	/* DISPLAY TABLE ROWS */
	
	foreach ( $theme_array as $theme => $value ) {
		$percent_usage = round( ( $value['count'] / $total_domains * 100 ), 2 );
		echo '<tr><td>' . $theme . '</td><td>' . $value['count'] . '</td><td><div style="background:url(' . $background_image . '); background-size:' . $percent_usage . 'px 20px; background-repeat:no-repeat; width:100px; color:#000000;"><b>&nbsp;' . $percent_usage . '%</b></div></td><td>' . $value['site_frontends'] . '</td><td>' . $value['site_backends'] . '</td></tr>';
	}
	echo '</table>';
}

?>